==> pandoc-crossref-0.3.13.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.13.0
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.13.0-6LoRRhsZrGqSQKJsmabPg-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.13.0-6LoRRhsZrGqSQKJsmabPg-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  88e9ee17c5b1f78b78d8dd82979fecb1
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.13.0-6LoRRhsZrGqSQKJsmabPg-pandoc-crossref-internal

depends:
    base-4.15.1.0 containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW directory-1.3.6.2
    filepath-1.4.2.1 microlens-0.4.13.0-8kbZITwqGed8vNsPXOVOwI
    microlens-mtl-0.2.0.2-Fvlx11Ndss4INlVisPiItr
    microlens-th-0.4.3.10-H2JRp2jh1X4pUCK34kQqn mtl-2.2.2
    pandoc-2.19.2-tnKQL55KCqDaeMjCKvBAe
    pandoc-types-1.22.2.1-HyUMJA5oF7Q5vQ3t8JI7nP
    syb-0.7.2.2-xZ7nFX3IOM5csbBnRE6zJ template-haskell-2.17.0.0
    text-1.2.5.0 utility-ht-0.0.16-Hh1rekezVS18V5gmrpopKI

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-crossref
version:              0.3.13.0
visibility:           public
id:                   pandoc-crossref-0.3.13.0-28PikxBoG1RiGWR7jxFso
key:                  pandoc-crossref-0.3.13.0-28PikxBoG1RiGWR7jxFso
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  13d0ecdfecc8fcc1edcc6b3d2668dfed
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.13.0-28PikxBoG1RiGWR7jxFso
depends:
    base-4.15.1.0 mtl-2.2.2 pandoc-2.19.2-tnKQL55KCqDaeMjCKvBAe
    pandoc-crossref-0.3.13.0-6LoRRhsZrGqSQKJsmabPg-pandoc-crossref-internal
    pandoc-types-1.22.2.1-HyUMJA5oF7Q5vQ3t8JI7nP text-1.2.5.0

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.13.0-29-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.13.0
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.13.0-7HBgMVzuKxZ1eRkN7mxM1X-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.13.0-7HBgMVzuKxZ1eRkN7mxM1X-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  221001ac16defd42901a955d79aa2a5c
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.13.0-7HBgMVzuKxZ1eRkN7mxM1X-pandoc-crossref-internal

depends:
    base-4.15.1.0 containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW directory-1.3.6.2
    filepath-1.4.2.1 microlens-0.4.13.0-8kbZITwqGed8vNsPXOVOwI
    microlens-mtl-0.2.0.2-Fvlx11Ndss4INlVisPiItr
    microlens-th-0.4.3.10-H2JRp2jh1X4pUCK34kQqn mtl-2.2.2
    pandoc-2.19.2-7yrAQK5GsfaF3LBlqvhkcz
    pandoc-types-1.22.2.1-6yi02BxI85IALnEdfaEQaz
    syb-0.7.2.2-8yUDZDN1zlNKFBJiDzETDr template-haskell-2.17.0.0
    text-1.2.5.0 utility-ht-0.0.16-4PxSiCkASTWJeCiZ5E7ASz

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-crossref
version:              0.3.13.0
visibility:           public
id:                   pandoc-crossref-0.3.13.0-GCGK7kY5QVyGbjF2ImNMZV
key:                  pandoc-crossref-0.3.13.0-GCGK7kY5QVyGbjF2ImNMZV
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  dc3450093a1442a361e277d0a76ffd9f
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pandoc-crossref-0.3.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.13.0-GCGK7kY5QVyGbjF2ImNMZV
depends:
    base-4.15.1.0 mtl-2.2.2 pandoc-2.19.2-7yrAQK5GsfaF3LBlqvhkcz
    pandoc-crossref-0.3.13.0-7HBgMVzuKxZ1eRkN7mxM1X-pandoc-crossref-internal
    pandoc-types-1.22.2.1-6yi02BxI85IALnEdfaEQaz text-1.2.5.0

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
